#!/bin/bash
set +ex

HOME_DIR="/home/phablet"

if [ -z "$1" ] || [ -z "$2" ]
then
    echo "You have to pass a device serial and packagearchive link"
    echo "$0 04bf2c50e294d599 archive.zip"
    exit -1
fi

exec_with_adb() {
    adb -s $ANDROID_SERIAL shell "$@"
}

exec_with_adb_user() {
    adb -s $ANDROID_SERIAL shell sudo -i -u phablet bash -ic "$@"
}

ANDROID_SERIAL=$1
packagearchive=$2
reboot_wait=30
network_wait=60
autopilot_timeout=1800

crash_dir=./crash
rm -rf $crash_dir
mkdir -p $crash_dir
results_dir=./results
rm -rf $results_dir
mkdir -p $results_dir

echo "Rebooting the phone will take approximately $reboot_wait seconds to settle"
adb -s $ANDROID_SERIAL reboot
adb -s $ANDROID_SERIAL wait-for-device
sleep $reboot_wait

# Set developer mode
rm .dev_mode || true
adb -s $ANDROID_SERIAL pull /.dev_mode
if [[ ! -a .dev_mode ]]; then
    exec_with_adb "touch /userdata/.writable_image"
    echo "Rebooting the phone to set dev mode."
    echo "It will take approximately $reboot_wait seconds to settle"
    adb -s $ANDROID_SERIAL reboot
    adb -s $ANDROID_SERIAL wait-for-device
    sleep $reboot_wait
    exec_with_adb "touch /.dev_mode"
fi

# Disable the intro screen
rm .intro_off || true
adb -s $ANDROID_SERIAL pull /.intro_off
if [[ ! -a .intro_off ]]; then
    exec_with_adb "dbus-send --system --print-reply --dest=org.freedesktop.Accounts /org/freedesktop/Accounts/User32011 org.freedesktop.DBus.Properties.Set string:com.canonical.unity.AccountsService string:demo-edges variant:boolean:false"

    #exec_with_adb_user $HOME_DIR/apexecutor/unlock_screen.py
    #exec_with_adb "sed -i 's/demo-edges=true/demo-edges=false/' /var/lib/AccountsService/users/phablet"
    exec_with_adb "touch /.intro_off"
    exec_with_adb "cat /var/lib/AccountsService/users/phablet"
    echo "Rebooting the phone to disable intro mode."
    echo "It will take approximately $reboot_wait seconds to settle"
    adb -s $ANDROID_SERIAL reboot
    adb -s $ANDROID_SERIAL wait-for-device
    sleep $reboot_wait
fi

# Setup info
setup_dir="$HOME_DIR/autopilot-testrunner"

# Cleanup old stuff
rm archive.zip *.xml dmesg.log dpkg-l.log top.log media-info
exec_with_adb "rm -r $setup_dir $HOME_DIR/archive* "
exec_with_adb "rm /var/crash/*"

# Initial setup
exec_with_adb_user "mkdir -p $setup_dir"
adb -s $ANDROID_SERIAL push autopilot-testrunner-touch-saucy/mediumtest_install_packages.sh "$setup_dir"
adb -s $ANDROID_SERIAL push autopilot-testrunner-touch-saucy/mediumtests_downgrade_pacakges.sh "$setup_dir"
adb -s $ANDROID_SERIAL push autopilot-testrunner-touch-saucy/run_all_autopilot.sh "$setup_dir"
adb -s $ANDROID_SERIAL push autopilot-testrunner-touch-saucy/unlock_screen.py "$setup_dir"

echo "Pausing $network_wait seconds before starting network"
sleep $network_wait
#exec_with_adb 'nmcli dev wifi connect ubuntu-qa-g-wpa-d password qalabwireless'
exec_with_adb 'nmcli dev wifi connect ubuntu-qa-g-wpa password qalabwireless'
exec_with_adb "apt-get update || apt-get update || apt-get update"
exec_with_adb apt-get -y install unzip autopilot-touch dpkg-dev

wget $packagearchive
adb -s $ANDROID_SERIAL push archive.zip $HOME_DIR
exec_with_adb_user "unzip $HOME_DIR/archive.zip -d $HOME_DIR"

# Setup the PPAs and local Archive
ppa_repos="ppa_sources"
rm $ppa_repos || true
touch $ppa_repos
for h in $hooks; do
    echo "Processing $h"
    if echo $h | grep D09add_ppa; then
        ppa=`echo $h | sed 's/D09add_ppa~\(.*\)~\(.*\)/ppa:\1\/\2/'`
	echo ${ppa} >> ${ppa_repos}
    fi
done

local_archive="deb $local_archive_source/$local_archive_name $local_archive_pocket/ "
if echo $local_archive | grep "http"; then
    local_archive=`sh -c "echo $local_archive | sed \"s/naartjie/10.97.0.6/\""`
    echo ${local_archive} >> ${ppa_repos}
fi
echo "Host side PPA repo list:"
cat $ppa_repos

adb -s $ANDROID_SERIAL push ${ppa_repos} /tmp/${ppa_repos}

exec_with_adb "$setup_dir/mediumtest_install_packages.sh"

# Add the test packages
exec_with_adb "sudo apt-get -y --force-yes install $test_packages"

exec_with_adb "top -n 1 -b | head -20 > /tmp/top.log"
exec_with_adb "dpkg -l > /tmp/dpkg-l.log"
exec_with_adb "dmesg > /tmp/dmesg.log"

# Setup to run the tests
adb -s $ANDROID_SERIAL pull /tmp/top.log $results_dir
adb -s $ANDROID_SERIAL pull /tmp/dmesg.log $results_dir
adb -s $ANDROID_SERIAL pull /tmp/dpkg-l.log $results_dir
adb -s $ANDROID_SERIAL pull /etc/media-info $results_dir

rm .setup_complete || true
adb -s $ANDROID_SERIAL pull /.setup_complete
if [[ ! -a .setup_complete ]]; then
    echo "SETUP FAILED - CAN'T CONTINUE"
else

    exec_with_adb 'nmcli dev wifi connect ubuntu-qa-g-wpa-d password qalabwireless'
    # Execute all of the test suites
    for suite in $test_suite; do
        echo "I: Ready to run tests"
        echo "Rebooting the phone will take approximately $reboot_wait seconds to settle"
        adb -s $ANDROID_SERIAL reboot
        sleep 5
        adb -s $ANDROID_SERIAL wait-for-device
        phablet-network --skip-setup -t 90s
        echo "I: Turning on the display"
        exec_with_adb "powerd-cli active &"
        exec_with_adb "powerd-cli display on bright &"
        echo "I: Unlocking screen"
        exec_with_adb "ps -ef|grep unity8"
        exec_with_adb_user "$setup_dir/unlock_screen.py"

        if [[ $suite == unity8 ]]; then
            echo "I: Unlocking screen (unity8)"
            exec_with_adb_user "stop unity8"
        fi
        adb -s $ANDROID_SERIAL wait-for-device
        echo "I: Setting screen active"
        exec_with_adb "powerd-cli active &"
        exec_with_adb "powerd-cli display on bright &"
        exec_with_adb "ps -ef|grep unity8"

        autopilot_results="${suite}_results.xml"
        exec_with_adb sudo -u phablet -i bash -ic "timeout --kill-after=30 --signal=2 $autopilot_timeout autopilot run -v -o /tmp/${autopilot_results} -f xml $suite 2>&1 | tee /tmp/autopilot.log"
        adb -s $ANDROID_SERIAL wait-for-device
        adb -s $ANDROID_SERIAL pull /tmp/$autopilot_results $results_dir
        adb -s $ANDROID_SERIAL pull /tmp/autopilot.log $results_dir
        exec_with_adb_user "rm /tmp/autopilot.log"
    done
fi

# Cleanup the test packages on the device
echo "I: Reverting the test packages"
echo "Rebooting the phone will take approximately $reboot_wait seconds to settle"
adb -s $ANDROID_SERIAL reboot
sleep 5
adb -s $ANDROID_SERIAL wait-for-device
phablet-network --skip-setup -t 90s
exec_with_adb "$setup_dir/mediumtests_downgrade_pacakges.sh"

echo "I: Gathering crash files (if any)"
adb -s $ANDROID_SERIAL pull /var/crash $crash_dir
ls $crash_dir

echo "I: Testing complete"
